Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateRecordRequest ¶
type CreateRecordRequest struct {
RecordType string `json:"type"`
Name string `json:"name"`
Content string `json:"content"`
TTL int `json:"ttl"`
}
CreateRecordRequest describes the json payload for creating a record
type CreateRecordResponse ¶
type CreateRecordResponse struct {
ID string `json:"id"`
RecordType string `json:"type"`
Name string `json:"name"`
Content string `json:"content"`
TTL int `json:"ttl"`
}
CreateRecordResponse describes the json response for creating a record
type GetRecordsResponse ¶
type GetRecordsResponse struct {
ID string `json:"id"`
RecordType string `json:"type"`
Name string `json:"name"`
Content string `json:"content"`
TTL int `json:"ttl"`
}
GetRecordsResponse describes the json response of a single record
type RemoveRecordResponse ¶
type RemoveRecordResponse struct {
}
RemoveRecordResponse describes the json response for removing a record
Click to show internal directories.
Click to hide internal directories.